# Put local requirements here

When you put [--find-links=requirements/local](https://pip.pypa.io/en/stable/reference/pip_wheel/#find-links)
then [pip](https://pip.pypa.io/) will look for libraries here.
